==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1HTTPIngressRuleValueFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1HTTPIngressRuleValueFluent<A extends V1beta1HTTPIngressRuleValueFluent<A>> extends Fluent<A>{


    public A addToPaths(int index,V1beta1HTTPIngressPath item);
    public A setToPaths(int index,V1beta1HTTPIngressPath item);
    public A addToPaths(V1beta1HTTPIngressPath... items);
    public A addAllToPaths(Collection<V1beta1HTTPIngressPath> items);
    public A removeFromPaths(V1beta1HTTPIngressPath... items);
    public A removeAllFromPaths(Collection<V1beta1HTTPIngressPath> items);
    
/**
 * This method has been deprecated, please use method buildPaths instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1HTTPIngressPath> getPaths();
    public List<V1beta1HTTPIngressPath> buildPaths();
    public V1beta1HTTPIngressPath buildPath(int index);
    public V1beta1HTTPIngressPath buildFirstPath();
    public V1beta1HTTPIngressPath buildLastPath();
    public V1beta1HTTPIngressPath buildMatchingPath(io.kubernetes.client.fluent.Predicate<V1beta1HTTPIngressPathBuilder> predicate);
    public A withPaths(List<V1beta1HTTPIngressPath> paths);
    public A withPaths(V1beta1HTTPIngressPath... paths);
    public Boolean hasPaths();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> addNewPath();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(V1beta1HTTPIngressPath item);
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> setNewPathLike(int index,V1beta1HTTPIngressPath item);
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editPath(int index);
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editFirstPath();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editLastPath();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editMatchingPath(io.kubernetes.client.fluent.Predicate<V1beta1HTTPIngressPathBuilder> predicate);

    public interface PathsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1HTTPIngressPathFluent<V1beta1HTTPIngressRuleValueFluent.PathsNested<N>>{

        
    public N and();    public N endPath();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1HTTPIngressRuleValueFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1HTTPIngressRuleValueFluent<A extends V1beta1HTTPIngressRuleValueFluent<A>> extends Fluent<A>{


    public A addToPaths(int index,V1beta1HTTPIngressPath item);
    public A setToPaths(int index,V1beta1HTTPIngressPath item);
    public A addToPaths(V1beta1HTTPIngressPath... items);
    public A addAllToPaths(Collection<V1beta1HTTPIngressPath> items);
    public A removeFromPaths(V1beta1HTTPIngressPath... items);
    public A removeAllFromPaths(Collection<V1beta1HTTPIngressPath> items);
    
/**
 * This method has been deprecated, please use method buildPaths instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1HTTPIngressPath> getPaths();
    public List<V1beta1HTTPIngressPath> buildPaths();
    public V1beta1HTTPIngressPath buildPath(int index);
    public V1beta1HTTPIngressPath buildFirstPath();
    public V1beta1HTTPIngressPath buildLastPath();
    public V1beta1HTTPIngressPath buildMatchingPath(io.kubernetes.client.fluent.Predicate<V1beta1HTTPIngressPathBuilder> predicate);
    public Boolean hasMatchingPath(io.kubernetes.client.fluent.Predicate<V1beta1HTTPIngressPathBuilder> predicate);
    public A withPaths(List<V1beta1HTTPIngressPath> paths);
    public A withPaths(V1beta1HTTPIngressPath... paths);
    public Boolean hasPaths();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> addNewPath();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(V1beta1HTTPIngressPath item);
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> setNewPathLike(int index,V1beta1HTTPIngressPath item);
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editPath(int index);
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editFirstPath();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editLastPath();
    public V1beta1HTTPIngressRuleValueFluent.PathsNested<A> editMatchingPath(io.kubernetes.client.fluent.Predicate<V1beta1HTTPIngressPathBuilder> predicate);

    public interface PathsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1HTTPIngressPathFluent<V1beta1HTTPIngressRuleValueFluent.PathsNested<N>>{

        
    public N and();    public N endPath();
}


}
